package internal

import (
	"context"
	"crypto/x509"
	"fmt"
	"github.com/wechatpay-apiv3/wechatpay-go/core"
	"github.com/wechatpay-apiv3/wechatpay-go/core/option"
	"github.com/wechatpay-apiv3/wechatpay-go/services/transferbatch"
	"github.com/wechatpay-apiv3/wechatpay-go/utils"
	"plugins/utils/weixin"
)

func transferBatchApiService(ctx context.Context, c *weixin.Server) (*transferbatch.TransferBatchApiService, error) {
	client, err := weixin.GetClient(ctx, c)
	if err != nil {
		return nil, err
	}
	svc := transferbatch.TransferBatchApiService{Client: client}
	return &svc, nil
}

func transferDetailApiService(ctx context.Context, c *weixin.Server) (*transferbatch.TransferDetailApiService, error) {
	mchPrivateKey, err := utils.LoadPrivateKeyWithPath(c.PrivateKeyPath)
	if err != nil {
		return nil, fmt.Errorf("MchID[%s] load merchant private key error:%v", c.MchID, err)
	}
	opts := []core.ClientOption{
		option.WithWechatPayAutoAuthCipher(c.MchID, c.MchCertificateSerialNumber, mchPrivateKey, c.MchAPIv3Key),
	}
	if c.CertificatePath != "" {
		payCert, err := utils.LoadCertificateWithPath(c.CertificatePath)
		if err != nil {
			return nil, fmt.Errorf("MchID[%s] load pay certificate error:%v", c.MchID, err)
		}
		opts = append(opts, option.WithWechatPayCertificate([]*x509.Certificate{payCert}))
	}
	client, err := core.NewClient(ctx, opts...)
	if err != nil {
		return nil, fmt.Errorf("MchID[%s] %v", c.MchID, err)
	}

	svc := transferbatch.TransferDetailApiService{Client: client}
	return &svc, nil
}

func verify(ctx context.Context, c *weixin.Server) error {
	err := c.Verify(ctx, "", "")
	if err != nil {
		return err
	}
	return nil
}
